@@ -1,12 +1,10 @@
-import base64
 import itertools
 import json
 import os
 import sys
 
-import six
-
 import click
+import six
 from click_aliases import ClickAliasedGroup
 
 from . import exceptions, localdev, messages
@@ -39,7 +37,10 @@ except ImportError:
     "-d",
     "--debug/--no-debug",
     default=False,
-    help=("Drop into the debugger if the command execution raises " "an exception."),
+    help=(
+        "Drop into the debugger if the command execution raises "
+        "an exception."
+    ),
 )
 @click.pass_context
 def cli(ctx, debug):
@@ -50,7 +51,8 @@ def cli(ctx, debug):
 
         def exception_handler(type, value, traceback):
             click.secho(
-                "\nAn exception occurred while executing the requested " "command:",
+                "\nAn exception occurred while executing the requested "
+                "command:",
                 fg="red",
             )
             hr(fg="red")
@@ -76,7 +78,9 @@ def cli(ctx, debug):
         if update_info["update_available"]:
             click.secho(
                 "New version {} is available. Type `divio version` to "
-                "show information about upgrading.".format(update_info["remote"]),
+                "show information about upgrading.".format(
+                    update_info["remote"]
+                ),
                 fg="yellow",
             )
 
@@ -93,7 +97,10 @@ def login_token_helper(ctx, value):
 @cli.command()
 @click.argument("token", required=False)
 @click.option(
-    "--check", is_flag=True, default=False, help="Check for current login status"
+    "--check",
+    is_flag=True,
+    default=False,
+    help="Check for current login status",
 )
 @click.pass_context
 def login(ctx, token, check):
@@ -116,7 +123,11 @@ def project():
 
 @project.command(name="list")
 @click.option(
-    "-g", "--grouped", is_flag=True, default=False, help="Group by organisation"
+    "-g",
+    "--grouped",
+    is_flag=True,
+    default=False,
+    help="Group by organisation",
 )
 @click.option("--json", "as_json", is_flag=True, default=False)
 @click.pass_obj
@@ -155,7 +166,9 @@ def project_list(obj, grouped, as_json):
             (six.text_type(website["id"]), website["domain"], website["name"])
         )
 
-    accounts = itertools.chain(groups["users"].items(), groups["organisations"].items())
+    accounts = itertools.chain(
+        groups["users"].items(), groups["organisations"].items()
+    )
 
     def sort_projects(items):
         return sorted(items, key=lambda x: x[0].lower())
@@ -204,6 +217,30 @@ def project_deploy_log(obj, remote_id, stage):
     obj.client.show_deploy_log(remote_id, stage)
 
 
+@project.command(name="logs")
+@click.argument("stage", default="test")
+@click.option(
+    "--tail", "tail", default=False, is_flag=True, help="tail the output"
+)
+@click.option(
+    "--utc", "utc", default=False, is_flag=True, help="show times in UTC"
+)
+@allow_remote_id_override
+@click.pass_obj
+def project_logs(obj, remote_id, stage, tail, utc):
+    """View logs"""
+    obj.client.show_log(remote_id, stage, tail, utc)
+
+
+@project.command(name="ssh")
+@click.argument("stage", default="test")
+@allow_remote_id_override
+@click.pass_obj
+def project_ssh(obj, remote_id, stage):
+    """Establish ssh connection"""
+    obj.client.ssh(remote_id, stage)
+
+
 @project.command(name="configure")
 @click.pass_obj
 def configure(obj):
@@ -301,7 +338,14 @@ def project_update(obj, strict):
 @allow_remote_id_override
 @click.pass_obj
 def environment_variables(
-    obj, remote_id, stage, show_all_vars, as_json, get_vars, set_vars, unset_vars
+    obj,
+    remote_id,
+    stage,
+    show_all_vars,
+    as_json,
+    get_vars,
+    set_vars,
+    unset_vars,
 ):
     """
     Get and set environment vars.
@@ -311,14 +355,19 @@ def environment_variables(
     if set_vars or unset_vars:
         set_vars = dict(set_vars)
         data = obj.client.set_custom_environment_variables(
-            website_id=remote_id, stage=stage, set_vars=set_vars, unset_vars=unset_vars
+            website_id=remote_id,
+            stage=stage,
+            set_vars=set_vars,
+            unset_vars=unset_vars,
         )
     else:
         data = obj.client.get_environment_variables(
             website_id=remote_id, stage=stage, custom_only=not show_all_vars
         )
         if get_vars:
-            data = {key: value for key, value in data.items() if key in get_vars}
+            data = {
+                key: value for key, value in data.items() if key in get_vars
+            }
     if as_json:
         click.echo(json.dumps(data, indent=2, sort_keys=True))
     else:
@@ -336,7 +385,9 @@ def project_status():
 
 @project.command(name="setup")
 @click.argument("slug")
-@click.option("-s", "--stage", default="test", help="pull data from environment")
+@click.option(
+    "-s", "--stage", default="test", help="pull data from environment"
+)
 @click.option(
     "-p",
     "--path",
@@ -481,7 +532,9 @@ def push_media(obj, remote_id, prefix, stage, noinput):
         click.secho(messages.PUSH_MEDIA_WARNING.format(stage=stage), fg="red")
         if not click.confirm("\nAre you sure you want to continue?"):
             return
-    localdev.push_media(obj.client, stage=stage, remote_id=remote_id, prefix=prefix)
+    localdev.push_media(
+        obj.client, stage=stage, remote_id=remote_id, prefix=prefix
+    )
 
 
 @project.group(name="import")
@@ -492,7 +545,9 @@ def project_import():
 @project_import.command(name="db")
 @click.argument("prefix", default=localdev.DEFAULT_SERVICE_PREFIX)
 @click.argument(
-    "dump-path", default=localdev.DEFAULT_DUMP_FILENAME, type=click.Path(exists=True)
+    "dump-path",
+    default=localdev.DEFAULT_DUMP_FILENAME,
+    type=click.Path(exists=True),
 )
 @click.pass_obj
 def import_db(obj, dump_path, prefix):
@@ -504,7 +559,10 @@ def import_db(obj, dump_path, prefix):
     project_home = utils.get_project_home()
     db_type = utils.get_db_type(prefix, path=project_home)
     localdev.ImportLocalDatabase(
-        client=obj.client, custom_dump_path=dump_path, prefix=prefix, db_type=db_type
+        client=obj.client,
+        custom_dump_path=dump_path,
+        prefix=prefix,
+        db_type=db_type,
     )()
 
 
@@ -567,14 +625,18 @@ def addon_upload(ctx):
 @addon.command(name="register")
 @click.argument("verbose_name")
 @click.argument("package_name")
-@click.option("-o", "--organisation", help="Register for an organisation", type=int)
+@click.option(
+    "-o", "--organisation", help="Register for an organisation", type=int
+)
 @click.pass_context
 def addon_register(ctx, package_name, verbose_name, organisation):
     """Register your addon on the Divio Cloud\n
     - Verbose Name:        Name of the Addon as it appears in the Marketplace.
     - Package Name:        System wide unique Python package name
     """
-    ret = ctx.obj.client.register_addon(package_name, verbose_name, organisation)
+    ret = ctx.obj.client.register_addon(
+        package_name, verbose_name, organisation
+    )
     click.echo(ret)
 
 
@@ -604,7 +666,9 @@ def boilerplate_validate(ctx):
 def boilerplate_upload(ctx, noinput):
     """Upload boilerplate to the Divio Cloud"""
     try:
-        ret = upload_boilerplate(ctx.obj.client, ctx.parent.params["path"], noinput)
+        ret = upload_boilerplate(
+            ctx.obj.client, ctx.parent.params["path"], noinput
+        )
     except exceptions.DivioException as exc:
         raise click.ClickException(*exc.args)
     click.echo(ret)
@@ -693,6 +757,8 @@ def doctor(obj, machine_readable, checks):
         click.echo(json.dumps(errors), nl=False)
     else:
         click.echo("Verifying your system setup")
-        exitcode = 0 if check_requirements_human(obj.client.config, checks) else 1
+        exitcode = (
+            0 if check_requirements_human(obj.client.config, checks) else 1
+        )
 
     sys.exit(exitcode)
