@@ -1,12 +1,14 @@
+import json
 import os
 import re
-from netrc import netrc
 import sys
+from netrc import netrc
 from time import sleep
 
-from six.moves.urllib_parse import urlparse
-
 import click
+from dateutil.parser import isoparse
+from six.moves.urllib_parse import urlparse
+from tzlocal import get_localzone
 
 from . import api_requests, messages, settings
 from .config import Config
@@ -34,6 +36,19 @@ def get_endpoint(host=None):
     return endpoint
 
 
+def get_service_color(service):
+    color_mapping = {
+        "web": "blue",
+        "cronjob": "bright_cyan",
+        "shell": "bright_red",
+        "worker": "bright_blue",
+    }
+    try:
+        return color_mapping[service]
+    except KeyError:
+        return "yellow"
+
+
 class CloudClient(object):
     def __init__(self, endpoint, debug=False):
         self.debug = debug
@@ -47,12 +62,13 @@ class CloudClient(object):
         host = urlparse(self.endpoint).hostname
         data = self.netrc.hosts.get(host)
         if data:
-            return {"Authorization": "Basic {}".format(data[2])}
+            return {"Authorization": "Token {}".format(data[2])}
         return {}
 
     def get_access_token_url(self):
         return "{}/{}".format(
-            self.endpoint.rstrip("/"), settings.ACCESS_TOKEN_URL_PATH.lstrip("/")
+            self.endpoint.rstrip("/"),
+            settings.ACCESS_TOKEN_URL_PATH.lstrip("/"),
         )
 
     def init_session(self):
@@ -64,10 +80,12 @@ class CloudClient(object):
         )
 
     def authenticate(self, token):
-        self.session.headers["Authorization"] = "Basic {}".format(token)
+        self.session.headers["Authorization"] = "Token {}".format(token)
 
     def login(self, token):
-        request = api_requests.LoginRequest(self.session, data={"token": token})
+        request = api_requests.LoginRequest(
+            self.session, data={"token": token}
+        )
         user_data = request()
 
         self.authenticate(token)
@@ -103,16 +121,133 @@ class CloudClient(object):
         request = api_requests.ProjectListRequest(self.session)
         return request()
 
+    def ssh(self, website_id, stage):
+        project_data = self.get_project(website_id)
+        try:
+            status = project_data["{}_status".format(stage)]
+        except KeyError:
+            click.secho(
+                "Environment with the name '{}' does not exist.".format(stage),
+                fg="red",
+            )
+            sys.exit(1)
+        if status["deployed_before"]:
+            try:
+                response = api_requests.EnvironmentRequest(
+                    self.session,
+                    url_kwargs={"environment_uuid": status["uuid"]},
+                )()
+                ssh_command = [
+                    "ssh",
+                    "-p",
+                    str(response["ssh_endpoint"]["port"]),
+                    "{}@{}".format(
+                        response["ssh_endpoint"]["user"],
+                        response["ssh_endpoint"]["host"],
+                    ),
+                ]
+                click.secho(" ".join(ssh_command), fg="green")
+                os.execvp("ssh", ssh_command)
+
+            except (KeyError, json.decoder.JSONDecodeError):
+                click.secho(
+                    "Error establishing ssh connection.".format(stage),
+                    fg="red",
+                )
+                sys.exit(1)
+
+        else:
+            click.secho(
+                "SSH connection not available: environment '{}' not deployed yet.".format(
+                    stage
+                ),
+                fg="yellow",
+            )
+            sys.exit(1)
+
+    def show_log(self, website_id, stage, tail=False, utc=True):
+        def print_log_data(data):
+            for entry in data:
+                dt = isoparse(entry["timestamp"])
+                if not utc:
+                    dt = dt.astimezone(get_localzone())
+                click.secho(
+                    "{} \u2502 {:^16} \u2502 {}".format(
+                        str(dt),
+                        click.style(
+                            entry["service"],
+                            fg=get_service_color(entry["service"]),
+                        ),
+                        entry["message"]
+                        .replace("\r", "")
+                        .replace("\x1b[6n", "")
+                        .replace("\x1b[J", "")
+                        .replace("\x1b[H", ""),
+                    )
+                )
+
+        project_data = self.get_project(website_id)
+        try:
+            status = project_data["{}_status".format(stage)]
+        except KeyError:
+            click.secho(
+                "Environment with the name '{}' does not exist.".format(stage),
+                fg="red",
+            )
+            sys.exit(1)
+        if status["deployed_before"]:
+            try:
+                # Make the initial log request
+                response = api_requests.LogRequest(
+                    self.session,
+                    url_kwargs={"environment_uuid": status["uuid"]},
+                )()
+
+                print_log_data(response["results"])
+
+                if tail:
+                    # Now continue to poll
+                    try:
+                        while True:
+                            # In this case, we can not construct the urls anymore and we have to rely on the previous response we got
+                            response = self.session.request(
+                                url=response["next"], method="GET"
+                            ).json()
+
+                            print_log_data(response["results"])
+                            if not response["results"]:
+                                sleep(1)
+                    except (KeyboardInterrupt, SystemExit):
+                        click.secho("Exiting...")
+                        sys.exit(1)
+            except (
+                KeyError,
+                json.decoder.JSONDecodeError,
+                api_requests.APIRequestError,
+            ):
+                click.secho("Error retrieving logs.".format(stage), fg="red")
+                sys.exit(1)
+
+        else:
+            click.secho(
+                "Logs not available: environment '{}' not deployed yet.".format(
+                    stage
+                ),
+                fg="yellow",
+            )
+            sys.exit(1)
+
     def show_deploy_log(self, website_id, stage):
         project_data = self.get_project(website_id)
         # If we have tried to deploy before, there will be a log
         try:
-            status = project_data["{}_status".format(stage)]["last_deployment"][
-                "status"
-            ]
+            status = project_data["{}_status".format(stage)][
+                "last_deployment"
+            ]["status"]
         except KeyError:
             click.secho(
-                "Environment with the name '{}' does not exist.".format(stage), fg="red"
+                "Environment with the name '{}' does not exist.".format(stage),
+                fg="red",
             )
             sys.exit(1)
         if status:
@@ -122,7 +257,9 @@ class CloudClient(object):
             click.echo_via_pager(output)
         else:
             click.secho(
-                "No {} environment deployed yet, no log available.".format(stage),
+                "No {} environment deployed yet, no log available.".format(
+                    stage
+                ),
                 fg="yellow",
             )
 
@@ -160,7 +297,10 @@ class CloudClient(object):
                 while response["is_deploying"]:
                     response = self.deploy_project_progress(website_id, stage)
                     bar.current_item = progress = response["deploy_progress"]
-                    if "main_percent" in progress and "extra_percent" in progress:
+                    if (
+                        "main_percent" in progress
+                        and "extra_percent" in progress
+                    ):
                         # update the difference of the current percentage
                         # to the new percentage
                         progress_percent = (
@@ -194,7 +334,8 @@ class CloudClient(object):
             return data[stage]
         except KeyError:
             click.secho(
-                "Environment with the name '{}' does not exist.".format(stage), fg="red"
+                "Environment with the name '{}' does not exist.".format(stage),
+                fg="red",
             )
             sys.exit(1)
 
@@ -293,12 +434,16 @@ class CloudClient(object):
 
     def download_media_request(self, website_id, stage):
         request = api_requests.DownloadMediaRequestRequest(
-            self.session, url_kwargs={"website_id": website_id}, data={"stage": stage}
+            self.session,
+            url_kwargs={"website_id": website_id},
+            data={"stage": stage},
         )
         return request()
 
     def download_media_progress(self, url):
-        request = api_requests.DownloadMediaProgressRequest(self.session, url=url)
+        request = api_requests.DownloadMediaProgressRequest(
+            self.session, url=url
+        )
         return request()
 
     def upload_db(self, website_id, stage, archive_path, prefix):
@@ -324,7 +469,9 @@ class CloudClient(object):
         return request()
 
     def upload_media_progress(self, url):
-        request = api_requests.UploadMediaFilesProgressRequest(self.session, url=url)
+        request = api_requests.UploadMediaFilesProgressRequest(
+            self.session, url=url
+        )
         return request()
 
     def get_environment_variables(self, website_id, stage, custom_only=True):
@@ -338,7 +485,9 @@ class CloudClient(object):
         )
         return request()
 
-    def set_custom_environment_variables(self, website_id, stage, set_vars, unset_vars):
+    def set_custom_environment_variables(
+        self, website_id, stage, set_vars, unset_vars
+    ):
         current_vars = self.get_environment_variables(
             website_id, stage, custom_only=True
         )
@@ -367,7 +516,9 @@ class CloudClient(object):
             # happens when there is no remote repository configured
             return None
 
-        raise click.ClickException("Could not get remote repository information.")
+        raise click.ClickException(
+            "Could not get remote repository information."
+        )
 
 
 class WritableNetRC(netrc):
