@@ -2,7 +2,6 @@ import os
 import struct
 
 import attr
-
 from cryptography.hazmat import backends
 from cryptography.hazmat.primitives import hashes, hmac
 from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
@@ -26,7 +25,9 @@ def iterchunks(data, chunksize):
 def minval(length):
     def validator(instance, attribute, value):
         if value < length:
-            raise ValueError("{} has to be >= {}".format(attribute.name, length))
+            raise ValueError(
+                "{} has to be >= {}".format(attribute.name, length)
+            )
 
     return validator
 
@@ -45,7 +46,9 @@ class CipherMixin(object):
     auth_hash = hashes.SHA256
 
     def encode_header(self, iv, salt, auth_salt):
-        return struct.pack(self.header_format, self.version, iv, salt, auth_salt)
+        return struct.pack(
+            self.header_format, self.version, iv, salt, auth_salt
+        )
 
     def decode_header(self, data):
         version, iv, salt, auth_salt = struct.unpack(self.header_format, data)
